@@ -9,7 +9,6 @@ from prettytable import PrettyTable
 from rich.console import Console
 from rich.progress import track
 from rich.table import Table
-from simple_term_menu import TerminalMenu
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
@@ -17,7 +16,6 @@ from neuralspace.constants import (
     COMMON_HEADERS,
     COMPLETED,
     COUNT,
-    CREATE_PROJECT_COMMAND,
     DATA,
     DEAD,
     ENTITIES,
@@ -39,7 +37,6 @@ from neuralspace.constants import (
     MODELS,
     N_REPLICAS,
     NER_METRICS,
-    NO,
     NUMBER_OF_EXAMPLES,
     NUMBER_OF_INTENTS,
     NUMBER_OF_MODELS,
@@ -56,8 +53,7 @@ from neuralspace.constants import (
     TRAINING_STATUS,
     TRAINING_TIME,
     TYPE,
-    YES,
-    neuralspace_url,
+    neuralspace_url, UPLOAD_DATASET_COMMAND,
 )
 from neuralspace.nlu.constants import (
     CREATE_EXAMPLE_URL,
@@ -145,7 +141,7 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
             console.print(table)
             console.print(
                 f"⏩ Upload data to your project using this command:"
-                f" [dark_orange3]{CREATE_PROJECT_COMMAND}[/dark_orange3]"
+                f" [dark_orange3]{UPLOAD_DATASET_COMMAND}[/dark_orange3]"
             )
         else:
             console.print("> [red]ERROR[/red] Failed ❌  to create project")
@@ -443,10 +439,10 @@ async def upload_dataset(
             else:
                 console.print(f"> [red]ERROR[/red] ❌ Failed to upload example with text [dark_orange3]{example['text']}[/dark_orange3]")
                 console.print(
-                    f"> Failed on example: \n {json.dumps(example, indent=4, ensure_ascii=False)}"
+                    f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
                 console.print(
-                    f"> Platform response: \n {json.dumps(json_response, indent=4)}"
+                    f"> Platform response: \n{json.dumps(json_response, indent=4)}"
                 )
                 error_examples.append(example)
                 if ignore_errors:
@@ -522,32 +518,25 @@ async def train_model(
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
 
-    console.print("[red]Do you really want to train the model: [/red]")
-    options = [YES, NO]
-    terminal_menu = TerminalMenu(options)
-    menu_entry_index = terminal_menu.show()
-    if options[menu_entry_index] == YES:
-        async with get_async_http_session().post(
-            url=f"{neuralspace_url()}/{TRAIN_MODEL_URL}",
-            data=json.dumps(payload),
-            headers=HEADERS,
-        ) as response:
-            json_response = await response.json(encoding="utf-8")
-            if is_success_status(response.status):
-                console.print(
-                    "> [deep_sky_blue2]INFO[/deep_sky_blue2] Training job queued successfully"
-                )
-                model_id = json_response[DATA]["model_id"]
-                last_model_status = await wait_till_training_completes(
-                    model_id, wait, wait_time
-                )
-            else:
-                console.print("> [red]ERROR[/red] Failed to queue training job")
-                console.print(f"> [red]ERROR[/red] {json_response['message']}")
-                last_model_status = None
-        return json_response, last_model_status
-    else:
-        console.print("Please read through and train the model again")
+    async with get_async_http_session().post(
+        url=f"{neuralspace_url()}/{TRAIN_MODEL_URL}",
+        data=json.dumps(payload),
+        headers=HEADERS,
+    ) as response:
+        json_response = await response.json(encoding="utf-8")
+        if is_success_status(response.status):
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] Training job queued successfully"
+            )
+            model_id = json_response[DATA]["model_id"]
+            last_model_status = await wait_till_training_completes(
+                model_id, wait, wait_time
+            )
+        else:
+            console.print("> [red]ERROR[/red] Failed to queue training job")
+            console.print(f"> [red]ERROR[/red] {json_response['message']}")
+            last_model_status = None
+    return json_response, last_model_status
 
 
 async def delete_models(model_id: Text) -> Dict[Text, Any]:
