@@ -11,10 +11,12 @@ from rich.table import Table
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
+    APP_IS_INSTALLED,
     AUTHORIZATION,
     COMMON_HEADERS,
     END_INDEX,
     FROM,
+    INSTALL_APP_COMMAND,
     INSTALL_APP_URL,
     LOGIN_URL,
     START_INDEX,
@@ -74,21 +76,26 @@ def is_success_status(status_code: int) -> bool:
 
 async def do_login(email: Text, password: Text):
     user_data = {"email": email, "password": password}
-    logger.debug(f"Login attempt for: {user_data}")
+    logger.debug(f"Login🚪 attempt for: {user_data}")
     async with get_async_http_session().post(
         url=f"{neuralspace_url()}/{LOGIN_URL}",
         data=json.dumps(user_data),
         headers=COMMON_HEADERS,
     ) as response:
         json_response = await response.json(encoding="utf-8")
-        logger.debug(f"Platform Response: {json_response}")
         if is_success_status(response.status):
             register_auth_token(json_response)
-            logger.info("Login successful!")
-            logger.debug(f"Credentials registered at {auth_path()}")
-            logger.info(f"Credentials: \n {json.dumps(json_response, indent=4)}")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅  Login successful!"
+            )
+            console.print(
+                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗝 Credentials registered at {auth_path()}"
+            )
+            console.print(
+                f"⏩  Install an app: [dark_orange3]{INSTALL_APP_COMMAND}[/dark_orange3]"
+            )
         else:
-            logger.error("Login failed! Please check your username and password")
+            console.print("Login failed ❌! Please check your username and password")
 
 
 async def app_install(name: Text):
@@ -102,15 +109,21 @@ async def app_install(name: Text):
         headers=HEADERS,
     ) as response:
         json_response = await response.json(encoding="utf-8")
-        logger.debug(
-            f"Platform Response: \n{json.dumps(json_response, indent=4, ensure_ascii=False)}"
-        )
         if is_success_status(response.status):
             register_auth_token(json_response)
-            logger.info("Install Successful!")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Install Successful!"
+            )
         else:
-            logger.error("Install Failed!")
-            logger.info(f"\n{json.dumps(json_response, indent=4, ensure_ascii=False)}")
+            if json_response["message"] == APP_IS_INSTALLED:
+                console.print(
+                    f"> [deep_sky_blue2]INFO[/deep_sky_blue2] [dark_orange3]{APP_IS_INSTALLED}[/dark_orange3]"
+                )
+            else:
+                console.print(" ❌ Install Failed!")
+                console.print(
+                    f"\n{json.dumps(json_response, indent=4, ensure_ascii=False)}"
+                )
 
 
 def get_list_chunks(items: List[Any], chunk_size: int):
